@@ -3,8 +3,6 @@ import tpmdata
 import multiprocessing
 import pprint
 import numpy as np
-import matplotlib as mpl
-mpl.use("GTK3Agg")
 import matplotlib.pyplot as plt
 from matplotlib import dates
 from astropy.time import Time
@@ -36,7 +34,7 @@ class StripChart:
         data = multiprocessing.Manager().dict()
         tpm_thread = multiprocessing.Process(target=get_tpm_packet, args=(data,))
         tpm_thread.start()
-        tpm_thread.join(1)
+        tpm_thread.join(2)
     
         if tpm_thread.is_alive():
             tpm_thread.kill()
@@ -55,7 +53,7 @@ class StripChart:
         data = multiprocessing.Manager().dict()
         tpm_thread = multiprocessing.Process(target=get_tpm_packet, args=(data,))
         tpm_thread.start()
-        tpm_thread.join(1)
+        tpm_thread.join(2)
     
         if tpm_thread.is_alive():
             tpm_thread.kill()
@@ -118,7 +116,7 @@ def main(args=None):
         data = multiprocessing.Manager().dict()
         tpm_thread = multiprocessing.Process(target=get_tpm_packet, args=(data,))
         tpm_thread.start()
-        tpm_thread.join(1)
+        tpm_thread.join(2)
     
         if tpm_thread.is_alive():
             tpm_thread.kill()
@@ -132,6 +130,7 @@ def main(args=None):
             fig = plt.figure(figsize=(6, 4))
             ax = fig.add_subplot(1, 1, 1)
             chart = StripChart(channel, fig, ax)
+            print(args.dt * 1000)
             anis.append(animation.FuncAnimation(fig, chart.update,
                                                 interval=args.dt * 1000))
             charts.append(chart)
@@ -146,7 +145,7 @@ def main(args=None):
             data = multiprocessing.Manager().dict()
             tpm_thread = multiprocessing.Process(target=get_tpm_packet, args=(data,))
             tpm_thread.start()
-            tpm_thread.join(1)
+            tpm_thread.join(2)
     
             if tpm_thread.is_alive():
                 tpm_thread.kill()
@@ -158,7 +157,7 @@ def main(args=None):
                 data = multiprocessing.Manager().dict()
                 tpm_thread = multiprocessing.Process(target=get_tpm_packet, args=(data,))
                 tpm_thread.start()
-                tpm_thread.join(1)
+                tpm_thread.join(2)
     
                 if tpm_thread.is_alive():
                     tpm_thread.kill()
