@@ -8,7 +8,7 @@ import numpy as np
 import textwrap
 from . import sdss_paths
 
-__version__ = '3.2.1'
+__version__ = '3.2.2'
 
 
 class APOGEERaw:
@@ -30,20 +30,10 @@ class APOGEERaw:
             raise FileNotFoundError(f"Could not find file {self.file.absolute()}")
         self.ext = ext
         self.args = args
-        header = fitsio.read_header(fil, ext=ext)
-        # if has_epics:
-        #     self.telemetry = epics_fetch.telemetry
-        #     dithers = self.telemetry.get('25m:apogee:ditherNamedPositions',
-        #                                  start=(Time.now() - 5 / 24 / 60).datetime,
-        #                                  end=Time.now().datetime,
-        #                                  scan_archives=False, interpolation='raw')
-        # else:
-        #     class Null:
-        #         pass
-        #     dithers = Null()
-        #     dithers.values = np.array([[0., 0.,], [0., 0.]])
-        # layer = self.image[layer_ind]
-        # An A dither is DITHPIX=12.994, a B dither is DITHPIX=13.499
+        try:
+            header = fitsio.read_header(fil, ext=ext)
+        except OSErrors:
+            header = fitsio.read_header(fil, ext=ext)
         if (header['DITHPIX'] - 12.994) < 0.05:
             self.dither = 'A'
         elif (header['DITHPIX'] - 13.494) < 0.05:
@@ -53,11 +43,22 @@ class APOGEERaw:
         self.exp_time = header['EXPTIME']
         self.isot = Time(header['DATE-OBS'])  # Local
         self.plate_id = header['PLATEID']
+        if "CONFIGID" in header.keys():
+            if isinstance(header["CONFIGID"], int):
+                self.design_id = header["DESIGNID"]
+                self.config_id = header["CONFIGID"]
+            else:
+                self.design_id = 0
+                self.config_id = 0 
+        else:
+            self.design_id = 0
+            self.config_id = 0 
+
         if "CARTID" in header.keys():
             if isinstance(header["CARTID"], int):
-                self.cart_id = header['CARTID']
+                self.cart_id = f"{header['CARTID']:.0f}"
             else:
-                self.cart_id = 0
+                self.cart_id = header["CARTID"]
         else:
             self.cart_id = 0
 
@@ -82,12 +83,11 @@ class APOGEERaw:
             self.seeing = header['SEEING']
         else:
             self.seeing = 0.0
-
+        self.mjd = self.file.absolute().parent.name
         self.quickred_data = np.array([[]])
-        self.quickred_file = ''
+        self.quickred_file = sdss_paths.ap_qr / f"{self.mjd}/apq-{self.exp_id}.fits"
         self.utr_file = ''
         self.utr_data = np.array([[]])
-        self.mjd = self.file.absolute().parent.name
 
     # noinspection PyTupleAssignmentBalance,PyTypeChecker
     def compute_offset(self, fibers=(60, 70), w0: int=1105, dw:int=40, sigma:float=1.2745):
@@ -110,7 +110,6 @@ class APOGEERaw:
         """
         w0 = int(w0)
         dw = int(dw)
-        self.quickred_file = sdss_paths.ap_qr / f"{self.mjd}/apq-{self.exp_id}.fits"
         if self.quickred_data.size == 0:
             if self.quickred_file.exists():
                 self.quickred_data = fitsio.read(self.quickred_file, 3)[0][0]
@@ -119,7 +118,7 @@ class APOGEERaw:
                                       / 'quickred/{}/ap1D-a-{}.fits.fz'
                                         ''.format(self.mjd, self.exp_id))
                 if not self.quickred_file.exists():
-                    print(f"Offsets for {self.file} could not be read")
+                    print(f"Offsets for {self.file.name} could not be read")
                     return np.nan
                 self.quickred_data = fitsio.read(self.quickred_file, 1)
         lower = w0 - dw // 2
@@ -149,53 +148,28 @@ class APOGEERaw:
                   ''.format(self.exp_id, diff, w0))
         return diff
 
-    def ap_test(self, ws=(900, 910), master_col=None, plot=False, legacy=False,
-                dome_flat_shape=None, n_fibers=300, print_it=False):
+    def ap_test(self, ws=(550, 910), master_col=None, plot=False,
+                print_it=False):
         if master_col is None:
             raise ValueError("APTest didn't receive a valid master_col: {}"
                              "".format(master_col))
-        if legacy:
-            self.utr_file = sdss_paths.ap_utr / f"{self.mjd}/apRaw-{self.exp_id}.fits"
-            if not self.utr_file.exists():
-                raise FileNotFoundError(f"Couldn't fine the file: {self.utr_file.as_posix()}")
-            try:
-                self.utr_data = fitsio.read(self.utr_file, 0)
-            except OSError as e:
-                if self.args.verbose:
-                    print('APTest for {} produced this error\n{}'.format(
-                        self.file, e))
-            slc0 = np.average(self.utr_data[::-1, ws[0]:ws[1]], axis=1)
-            # print(slc0.mean(), slc0.shape, slc0[0])
-            slc = np.zeros(n_fibers)
-            for j in range(n_fibers):
-                for k in range(10):
-                    if dome_flat_shape[j, k] != 0:
-                        slc[j] += slc0[dome_flat_shape[j, k]]
-            # print(slc.mean(), slc.shape, slc[100])
-
-        else:
-            if self.quickred_data.size == 0:
-                if self.quickred_file.exists():
-                    self.quickred_data = fitsio.read(self.quickred_file, 3)[0][0]
-                else:
-                    self.quickred_file = (sdss_paths.ap_qr
-                                          / 'quickred/{}/ap1D-a-{}.fits.fz'
-                                            ''.format(self.mjd, self.exp_id))
-                    if not self.quickred_file.exists():
-                        print(f"Offsets for {self.file} could not be read")
-                        return np.nan
-                    self.quickred_data = fitsio.read(self.quickred_file, 1)
-            slc = np.average(self.quickred_data[:, ws[0]:ws[1]], axis=1)
-        # print(master_col.mean(), master_col.shape, master_col[100])
+        if self.quickred_data.size == 0:
+            if self.quickred_file.exists():
+                self.quickred_data = fitsio.read(self.quickred_file, 3)[0][0]
+            else:
+                self.quickred_file = (sdss_paths.ap_qr
+                                      / 'quickred/{}/ap1D-a-{}.fits.fz'
+                                        ''.format(self.mjd, self.exp_id))
+                if not self.quickred_file.exists():
+                    print(f"Offsets for {self.file.name} could not be read")
+                    return [], [], np.nan
+                self.quickred_data = fitsio.read(self.quickred_file, 1)
+        slc = np.median(self.quickred_data[:, ws[0]:ws[1]], axis=1)
         flux_ratio = slc / master_col
-        # flux_ratio = flux_ratio / flux_ratio.sum() / flux_ratio.shape[0]
-        flux_ratio = flux_ratio / flux_ratio.sum() * flux_ratio.shape[0]
-        # print(flux_ratio.mean(), flux_ratio.shape, flux_ratio[100])
         bad_data = ((flux_ratio == np.inf)
                     | (flux_ratio == -np.inf)
                     | np.isnan(flux_ratio))
         flux_ratio[bad_data] = np.nan
-        avg = np.nanmean(flux_ratio)
         missing = flux_ratio < 0.2
         faint = (flux_ratio < 0.7) & (0.2 <= flux_ratio)
         bright = ~missing & ~faint
@@ -205,7 +179,6 @@ class APOGEERaw:
         missing_bundles = self.create_bundles(i_missing)
         faint_bundles = self.create_bundles(i_faint)
         if print_it:
-
             print(textwrap.fill('Missing Fibers: {}'.format(missing_bundles),
                                 80))
             print(textwrap.fill('Faint Fibers: {}'.format(faint_bundles), 80))
@@ -228,9 +201,9 @@ class APOGEERaw:
             ax.axhline(0.2, c=(0.933, 0.466, 0.2))
             ax.set_title('APOGEE Fiber Relative Intensity {}'.format(
                 self.exp_id), size=15)
-            fig.show()
+            plt.show()
 
-        return missing_bundles, faint_bundles, avg
+        return missing_bundles, faint_bundles, flux_ratio
 
     @staticmethod
     def create_bundles(subset):
@@ -294,7 +267,7 @@ def main():
     else:
         raise Exception('No date specified')
     # print(data_dir)
-    for path in data_dir.rglob('apR*.apz'):
+    for path in data_dir.rglob('apq*.fits'):
         print(path)
 
 
